==> tenant-domain-1.0.12-20200214.022750-2-sources.jar: com/xforceplus/domain/user/UserDto.java <==
package com.xforceplus.domain.user;


import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonView;
import com.xforceplus.domain.org.OrgDto;
import io.geewit.core.jackson.view.View;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.Date;
import java.util.List;
import java.util.Set;

@ApiModel(value = "用户")
public class UserDto<R extends RoleDto, O extends OrgDto<O>> {
    @ApiModelProperty("用户id")
    @JsonView(View.class)
    protected Long userId;

    @ApiModelProperty("租户id")
    @JsonView(View.class)
    protected Long tenantId;

    @ApiModelProperty("账户id")
    @JsonView(View.class)
    protected Long accountId;

    @ApiModelProperty("用户代码")
    @JsonView(View.class)
    protected String userCode;

    @ApiModelProperty(value = "用户编码", notes = "预留给业务系统使用")
    @JsonView(View.class)
    protected String userNumber;

    @ApiModelProperty(value = "用户名称", notes = "预留给业务系统使用")
    @JsonView(View.class)
    protected String userName;

    @JsonView(View.class)
    protected String userPhone;

    @ApiModelProperty(value = "性别")
    @JsonView(View.class)
    protected Integer userSex;

    @JsonView(View.class)
    protected String userEmailAddr;

    @JsonView(View.class)
    protected String userIdCard;

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+08")
    @JsonView(View.class)
    protected Date userPeriodTime;

    @JsonView(View.class)
    protected String userWorkTel;

    @JsonView(View.class)
    protected Integer activeStatus;

    @ApiModelProperty(value = "启用状态", notes = "1:启用, 0:注销")
    @JsonView(View.class)
    protected Integer status;

    @JsonView(View.class)
    protected String contactAddr;

    @JsonView(View.class)
    protected String businessExtensionAttribute;

    @ApiModelProperty("关联角色集合")
    @JsonView(View.Info.class)
    protected Set<R> roles;

    @ApiModelProperty("所属组织集合")
    @JsonView(View.Info.class)
    protected List<O> currentOrgs;

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getUserNumber() {
        return userNumber;
    }

    public void setUserNumber(String userNumber) {
        this.userNumber = userNumber;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserPhone() {
        return userPhone;
    }

    public void setUserPhone(String userPhone) {
        this.userPhone = userPhone;
    }

    public Integer getUserSex() {
        return userSex;
    }

    public void setUserSex(Integer userSex) {
        this.userSex = userSex;
    }

    public String getUserEmailAddr() {
        return userEmailAddr;
    }

    public void setUserEmailAddr(String userEmailAddr) {
        this.userEmailAddr = userEmailAddr;
    }

    public String getUserIdCard() {
        return userIdCard;
    }

    public void setUserIdCard(String userIdCard) {
        this.userIdCard = userIdCard;
    }

    public Date getUserPeriodTime() {
        return userPeriodTime;
    }

    public void setUserPeriodTime(Date userPeriodTime) {
        this.userPeriodTime = userPeriodTime;
    }

    public String getUserWorkTel() {
        return userWorkTel;
    }

    public void setUserWorkTel(String userWorkTel) {
        this.userWorkTel = userWorkTel;
    }

    public Integer getActiveStatus() {
        return activeStatus;
    }

    public void setActiveStatus(Integer activeStatus) {
        this.activeStatus = activeStatus;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getContactAddr() {
        return contactAddr;
    }

    public void setContactAddr(String contactAddr) {
        this.contactAddr = contactAddr;
    }

    public String getBusinessExtensionAttribute() {
        return businessExtensionAttribute;
    }

    public void setBusinessExtensionAttribute(String businessExtensionAttribute) {
        this.businessExtensionAttribute = businessExtensionAttribute;
    }

    public Set<R> getRoles() {
        return roles;
    }

    public void setRoles(Set<R> roles) {
        this.roles = roles;
    }

    public List<O> getCurrentOrgs() {
        return currentOrgs;
    }

    public void setCurrentOrgs(List<O> currentOrgs) {
        this.currentOrgs = currentOrgs;
    }

    @Override
    public String toString() {
        return "UserDto{" +
                "userId=" + userId +
                ", tenantId=" + tenantId +
                ", accountId=" + accountId +
                ", userCode='" + userCode + '\'' +
                ", userNumber='" + userNumber + '\'' +
                ", userName='" + userName + '\'' +
                ", userPhone='" + userPhone + '\'' +
                ", userSex=" + userSex +
                ", userEmailAddr='" + userEmailAddr + '\'' +
                ", userIdCard='" + userIdCard + '\'' +
                ", userPeriodTime=" + userPeriodTime +
                ", userWorkTel='" + userWorkTel + '\'' +
                ", activeStatus=" + activeStatus +
                ", status=" + status +
                ", contactAddr='" + contactAddr + '\'' +
                ", businessExtensionAttribute='" + businessExtensionAttribute + '\'' +
                '}';
    }
}

==> tenant-domain-1.0.45-20200316.050223-1-sources.jar: com/xforceplus/domain/user/UserDto.java <==
package com.xforceplus.domain.user;


import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonView;
import com.xforceplus.domain.org.OrgDto;
import com.xforceplus.tenant.security.core.domain.IAuthorizedUser;
import io.geewit.core.jackson.view.View;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.Date;
import java.util.Set;


@ApiModel(value = "用户")
public class UserDto<O extends OrgDto<O>, R extends RoleDto> extends UserRaw implements IAuthorizedUser<O, R> {
    @ApiModelProperty("公司集合")
    protected Set<O> companies;

    @ApiModelProperty("用户角色id集合")
    protected Set<R> roles;

    @ApiModelProperty("最近的上一级公司集合")
    protected Set<O> parentCompanies;

    @ApiModelProperty("资源码集合")
    protected Set<String> resourceCodes;

    @ApiModelProperty("所在租户开启的应用id集合")
    protected Set<Long> appIds;

    @ApiModelProperty("所属以及下级组织集合")
    protected Set<O> orgs;

    @ApiModelProperty("所在组织集合")
    protected Set<O> currentOrgs;

    @ApiModelProperty(value = "用户编码", notes = "预留给业务系统使用")
    @JsonView(View.class)
    protected String userNumber;

    @ApiModelProperty(value = "用户名称", notes = "预留给业务系统使用")
    @JsonView(View.class)
    protected String userName;

    @JsonView(View.class)
    protected String userPhone;

    @ApiModelProperty(value = "性别")
    @JsonView(View.class)
    protected Integer userSex;

    @JsonView(View.class)
    protected String userEmailAddr;

    @JsonView(View.class)
    protected String userIdCard;

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+08")
    @JsonView(View.class)
    protected Date userPeriodTime;

    @JsonView(View.class)
    protected String userWorkTel;

    @JsonView(View.class)
    protected Integer activeStatus;

    @ApiModelProperty(value = "启用状态", notes = "1:启用, 0:注销")
    @JsonView(View.class)
    protected Integer status;

    @JsonView(View.class)
    protected String contactAddr;

    @JsonView(View.class)
    protected String businessExtensionAttribute;

    public String getUserNumber() {
        return userNumber;
    }

    public void setUserNumber(String userNumber) {
        this.userNumber = userNumber;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserPhone() {
        return userPhone;
    }

    public void setUserPhone(String userPhone) {
        this.userPhone = userPhone;
    }

    public Integer getUserSex() {
        return userSex;
    }

    public void setUserSex(Integer userSex) {
        this.userSex = userSex;
    }

    public String getUserEmailAddr() {
        return userEmailAddr;
    }

    public void setUserEmailAddr(String userEmailAddr) {
        this.userEmailAddr = userEmailAddr;
    }

    public String getUserIdCard() {
        return userIdCard;
    }

    public void setUserIdCard(String userIdCard) {
        this.userIdCard = userIdCard;
    }

    public Date getUserPeriodTime() {
        return userPeriodTime;
    }

    public void setUserPeriodTime(Date userPeriodTime) {
        this.userPeriodTime = userPeriodTime;
    }

    public String getUserWorkTel() {
        return userWorkTel;
    }

    public void setUserWorkTel(String userWorkTel) {
        this.userWorkTel = userWorkTel;
    }

    public Integer getActiveStatus() {
        return activeStatus;
    }

    public void setActiveStatus(Integer activeStatus) {
        this.activeStatus = activeStatus;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getContactAddr() {
        return contactAddr;
    }

    public void setContactAddr(String contactAddr) {
        this.contactAddr = contactAddr;
    }

    public String getBusinessExtensionAttribute() {
        return businessExtensionAttribute;
    }

    public void setBusinessExtensionAttribute(String businessExtensionAttribute) {
        this.businessExtensionAttribute = businessExtensionAttribute;
    }

    public Set<O> getCompanies() {
        return companies;
    }

    public void setCompanies(Set<O> companies) {
        this.companies = companies;
    }

    public Set<R> getRoles() {
        return roles;
    }

    public void setRoles(Set<R> roles) {
        this.roles = roles;
    }

    public Set<O> getParentCompanies() {
        return parentCompanies;
    }

    public void setParentCompanies(Set<O> parentCompanies) {
        this.parentCompanies = parentCompanies;
    }

    @Override
    public Set<String> getResourceCodes() {
        return resourceCodes;
    }

    public void setResourceCodes(Set<String> resourceCodes) {
        this.resourceCodes = resourceCodes;
    }

    @Override
    public Set<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(Set<Long> appIds) {
        this.appIds = appIds;
    }

    public Set<O> getOrgs() {
        return orgs;
    }

    public void setOrgs(Set<O> orgs) {
        this.orgs = orgs;
    }

    public Set<O> getCurrentOrgs() {
        return currentOrgs;
    }

    public void setCurrentOrgs(Set<O> currentOrgs) {
        this.currentOrgs = currentOrgs;
    }
}
